Index: main/waeup.kofa/trunk/src/waeup/kofa/image/README.txt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/image/README.txt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/image/README.txt	(revision 7811)
@@ -1,9 +1,9 @@
-waeup.sirp.image -- handling image files
+waeup.kofa.image -- handling image files
 ========================================
 
-The image file widget is built on top of the :class:`SIRPImageFile` object::
-
-  >>> from waeup.sirp.image import SIRPImageFile
-  >>> file = SIRPImageFile('foo.jpg', 'mydata')
+The image file widget is built on top of the :class:`KOFAImageFile` object::
+
+  >>> from waeup.kofa.image import KOFAImageFile
+  >>> file = KOFAImageFile('foo.jpg', 'mydata')
   >>> file.filename
   'foo.jpg'
@@ -16,5 +16,5 @@
   'mydata'
 
-We can also create SIRPImageFile objects from file-like objects::
+We can also create KOFAImageFile objects from file-like objects::
 
   >>> from StringIO import StringIO
@@ -36,5 +36,5 @@
 ----------------
 
-The SIRPImageFile object normally stores the file data using ZODB
+The KOFAImageFile object normally stores the file data using ZODB
 persistence. Files can however also be stored by tramline.  If
 tramline is installed in Apache, the Tramline takes care of generating
@@ -73,5 +73,5 @@
 just '1') will now be created::
 
-  >>> file = SIRPImageFile('foo.jpg', '1')
+  >>> file = KOFAImageFile('foo.jpg', '1')
 
 The data is now '1', referring to the real file::
@@ -102,5 +102,5 @@
 We expect the same behavior as when tramline is not installed::
 
-  >>> file = SIRPImageFile('foo.jpg', 'data')
+  >>> file = KOFAImageFile('foo.jpg', 'data')
   >>> f = file.file
   >>> f.read()
@@ -114,11 +114,11 @@
   >>> shutil.rmtree(dirpath)
 
-Support for :mod:`waeup.sirp.imagestorage`
+Support for :mod:`waeup.kofa.imagestorage`
 ------------------------------------------
 
 The behaviour shown above can be used for any Zope3 application. With
-:mod:`waeup.sirp` we use a special file retrieval utility defined in
-:mod:`waeup.sirp.imagestorage`. As this utility is based on
-:mod:`waeup.sirp` internal stuff we do not show it here but in the
+:mod:`waeup.kofa` we use a special file retrieval utility defined in
+:mod:`waeup.kofa.imagestorage`. As this utility is based on
+:mod:`waeup.kofa` internal stuff we do not show it here but in the
 tests that come with that storage type.
 
@@ -135,5 +135,5 @@
 The `ImageFile` field accepts only certain content types:
 
-  >>> from waeup.sirp.image.schema import ImageFile
+  >>> from waeup.kofa.image.schema import ImageFile
   >>> from zope.publisher.browser import TestRequest
   >>> field = ImageFile(__name__='foo', title=u'Foo')
@@ -141,12 +141,12 @@
   Traceback (most recent call last):
   ...
-  WrongType: ('asd', <class 'waeup.sirp.image.image.SIRPImageFile'>, 'foo')
+  WrongType: ('asd', <class 'waeup.kofa.image.image.KOFAImageFile'>, 'foo')
 
 which means: `ImageFile` fields should better contain
-:class:`SIRPImageFile` instances.
-
-We can store normal :class:`SIRPImageFile` instances:
-
-  >>> field.validate(SIRPImageFile('bar.jpg', 'data')) is None
+:class:`KOFAImageFile` instances.
+
+We can store normal :class:`KOFAImageFile` instances:
+
+  >>> field.validate(KOFAImageFile('bar.jpg', 'data')) is None
   True
 
@@ -173,9 +173,9 @@
 
   >>> field.validate(
-  ...     SIRPImageFile('bar.jpg', '123456789012')) is None
-  True
-
-  >>> field.validate(
-  ...     SIRPImageFile('bar.jpg', '12345')) is None
+  ...     KOFAImageFile('bar.jpg', '123456789012')) is None
+  True
+
+  >>> field.validate(
+  ...     KOFAImageFile('bar.jpg', '12345')) is None
   True
 
@@ -183,5 +183,5 @@
 
   >>> field.validate(
-  ...     SIRPImageFile('bar.jpg', '1234567890123'))
+  ...     KOFAImageFile('bar.jpg', '1234567890123'))
   Traceback (most recent call last):
   ...
@@ -189,5 +189,5 @@
 
   >>> field.validate(
-  ...     SIRPImageFile('bar.jpg', '1234'))
+  ...     KOFAImageFile('bar.jpg', '1234'))
   Traceback (most recent call last):
   ...
@@ -198,10 +198,10 @@
 ----------------------------
 
-SIRPImageFile does not reproduce the broken unequal comparison from
+KOFAImageFile does not reproduce the broken unequal comparison from
 its base:
 
-  >>> f1 = SIRPImageFile('bar.jpg', '123456789')
-  >>> f2 = SIRPImageFile('bar.jpg', '123456789')
-  >>> f3 = SIRPImageFile('baz.jpg', '1234')
+  >>> f1 = KOFAImageFile('bar.jpg', '123456789')
+  >>> f2 = KOFAImageFile('bar.jpg', '123456789')
+  >>> f3 = KOFAImageFile('baz.jpg', '1234')
   >>> f1 == f2
   True
Index: main/waeup.kofa/trunk/src/waeup/kofa/image/__init__.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/image/__init__.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/image/__init__.py	(revision 7811)
@@ -3,8 +3,8 @@
 Includings schemas, widgets and the content components.
 """
-from waeup.sirp.image.image import SIRPImageFile, createSIRPImageFile
+from waeup.kofa.image.image import KOFAImageFile, createKOFAImageFile
 
 __all__ = [
-    "SIRPImageFile",
-    "createSIRPImageFile",
+    "KOFAImageFile",
+    "createKOFAImageFile",
     ]
Index: main/waeup.kofa/trunk/src/waeup/kofa/image/browser/__init__.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/image/browser/__init__.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/image/browser/__init__.py	(revision 7811)
@@ -1,5 +1,5 @@
 # The public API part
 # Contains the widgets defined for image files.
-from waeup.sirp.image.browser.widget import (
+from waeup.kofa.image.browser.widget import (
     EncodingImageFileWidget, ThumbnailWidget,
     )
Index: main/waeup.kofa/trunk/src/waeup/kofa/image/browser/tests/image.txt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/image/browser/tests/image.txt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/image/browser/tests/image.txt	(revision 7811)
@@ -12,8 +12,8 @@
 
   >>> import os
-  >>> from waeup.sirp.image import SIRPImageFile
+  >>> from waeup.kofa.image import KOFAImageFile
   >>> testimage = os.path.join(os.path.dirname(__file__), 'sample.jpg')
   >>> testimage2 = os.path.join(os.path.dirname(__file__), 'sample2.jpg')
-  >>> some_file = SIRPImageFile('foo.jpg', open(testimage, 'rb').read())
+  >>> some_file = KOFAImageFile('foo.jpg', open(testimage, 'rb').read())
   >>> some_file.filename
   'foo.jpg'
@@ -26,5 +26,5 @@
   >>> from hurry.file.browser import DownloadWidget
   >>> from hurry.file.schema import File
-  >>> from waeup.sirp.image.schema import ImageFile
+  >>> from waeup.kofa.image.schema import ImageFile
   >>> from zope.publisher.browser import TestRequest
   >>> field = ImageFile(__name__='foo', title=u'Foo')
@@ -51,5 +51,5 @@
 Instead of downloading, we can also use a thumbnail widget:
 
-  >>> from waeup.sirp.image.browser import ThumbnailWidget
+  >>> from waeup.kofa.image.browser import ThumbnailWidget
   >>> request = TestRequest(form={'field.foo': FileUpload(some_file)})
   >>> widget = ThumbnailWidget(field, request)
@@ -61,5 +61,5 @@
 data already available, and no data in request:
 
-  >>> from waeup.sirp.image.browser import EncodingImageFileWidget
+  >>> from waeup.kofa.image.browser import EncodingImageFileWidget
   >>> field = ImageFile(__name__='foo', title=u'Foo', required=False)
   >>> field = field.bind(None)
@@ -166,5 +166,5 @@
 prepare some new file:
 
-  >>> another_file = SIRPImageFile('bar.txt', 'bar contents')
+  >>> another_file = KOFAImageFile('bar.txt', 'bar contents')
 
 We happen to know, due to the implementation of
@@ -200,5 +200,5 @@
 ---------------------------
 
-As :class:`waeup.sirp.image.SIRPImageFile` objects support storing
+As :class:`waeup.kofa.image.KOFAImageFile` objects support storing
 image data by using external 'storages', also our widgets should do
 so.
@@ -220,5 +220,5 @@
   ...         contents = f.read()
   ...         id_string = hashlib.md5(contents).hexdigest()
-  ...         result = SIRPImageFile(filename, id_string)
+  ...         result = KOFAImageFile(filename, id_string)
   ...         self.storage[id_string] = contents
   ...         return result
@@ -260,9 +260,9 @@
 We now want to simulate, that the field contains already data,
 identified by some `file_id`. To do so, we first store the data in our
-file retrieval and then create a SIRPImageFile object with that
+file retrieval and then create a KOFAImageFile object with that
 file_id stored:
 
-  >>> from waeup.sirp.image import createSIRPImageFile
-  >>> image = createSIRPImageFile(
+  >>> from waeup.kofa.image import createKOFAImageFile
+  >>> image = createKOFAImageFile(
   ...     'sample.jpg', open(testimage, 'rb'))
   >>> file_id = image.data
@@ -274,5 +274,5 @@
   '9feac4265077922000aa8b88748e25be'
 
-The new file was stored by our utility, as createSIRPImageFile looks
+The new file was stored by our utility, as createKOFAImageFile looks
 up IFileRetrieval utilities and uses them:
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/image/browser/tests/test_views.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/image/browser/tests/test_views.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/image/browser/tests/test_views.py	(revision 7811)
@@ -30,5 +30,5 @@
 from hurry.file.file import IdFileRetrieval
 from hurry.file.interfaces import IFileRetrieval
-from waeup.sirp.image.browser.views import HurryFileView
+from waeup.kofa.image.browser.views import HurryFileView
 from zope.component import getMultiAdapter, provideUtility
 from zope.publisher.browser import TestRequest
@@ -41,9 +41,9 @@
 class ImageBrowserViewsLayer(object):
     """A layer that registers all components in
-       `waeup.sirp.image.browser.views` module.
+       `waeup.kofa.image.browser.views` module.
     """
     @classmethod
     def setUp(cls):
-        grok.testing.grok('waeup.sirp.image.browser.views')
+        grok.testing.grok('waeup.kofa.image.browser.views')
 
     @classmethod
Index: main/waeup.kofa/trunk/src/waeup/kofa/image/browser/widget.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/image/browser/widget.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/image/browser/widget.py	(revision 7811)
@@ -19,5 +19,5 @@
 """
 import os
-from waeup.sirp.image import SIRPImageFile
+from waeup.kofa.image import KOFAImageFile
 from hurry.file.browser.widget import (
     EncodingFileWidget, DownloadWidget, FakeFieldStorage)
@@ -62,5 +62,5 @@
                 seek(0)
                 return retrieval.createFile(input.filename, input)
-            return SIRPImageFile(input.filename, data)
+            return KOFAImageFile(input.filename, data)
         else:
             return self.context.missing_value
@@ -143,5 +143,5 @@
         data = file_id.decode('base64')
         filename, filedata = data.split('\n', 1)
-        return SIRPImageFile(filename, filedata)
+        return KOFAImageFile(filename, filedata)
 
 class ThumbnailWidget(DownloadWidget):
Index: main/waeup.kofa/trunk/src/waeup/kofa/image/interfaces.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/image/interfaces.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/image/interfaces.py	(revision 7811)
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""Interfaces for waeup.sirp.image
+"""Interfaces for waeup.kofa.image
 """
 from hurry.file.interfaces import IFile, IFileRetrieval, IHurryFile
@@ -23,9 +23,9 @@
     """Image file field.
     """
-    
-class ISIRPImageFile(IHurryFile):
+
+class IKOFAImageFile(IHurryFile):
     """Image file.
     """
-    
+
 class IImageFileRetrieval(IFileRetrieval):
     """A file retrieval for images.
Index: main/waeup.kofa/trunk/src/waeup/kofa/image/schema.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/image/schema.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/image/schema.py	(revision 7811)
@@ -22,6 +22,6 @@
 from zope.schema.interfaces import TooBig, TooSmall
 from hurry.file.schema import File
-from waeup.sirp.image.interfaces import IImageFile
-from waeup.sirp.image.image import SIRPImageFile
+from waeup.kofa.image.interfaces import IImageFile
+from waeup.kofa.image.image import KOFAImageFile
 
 class MinMaxSize(object):
@@ -82,3 +82,3 @@
     implements(IImageFile)
 
-    _type = SIRPImageFile
+    _type = KOFAImageFile

Index: main/waeup.kofa/trunk/src/waeup/kofa/image/image.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/image/image.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/image/image.py	(revision 7811)
@@ -23,7 +23,7 @@
 from zope.component import getUtility
 from zope.interface import implements
-from waeup.sirp.image.interfaces import ISIRPImageFile
+from waeup.kofa.image.interfaces import IKOFAImageFile
 
-class SIRPImageFile(HurryFile):
+class KOFAImageFile(HurryFile):
     """A file prepared for storing image files.
 
@@ -32,8 +32,8 @@
     regular hurry files.
 
-    To create a :class:`SIRPImageFile` you should use
-    :func:`createSIRPImageFile`.
+    To create a :class:`KOFAImageFile` you should use
+    :func:`createKOFAImageFile`.
     """
-    implements(ISIRPImageFile)
+    implements(IKOFAImageFile)
 
     def __ne__(self, other):
@@ -45,5 +45,5 @@
             return True
 
-def createSIRPImageFile(filename, f):
+def createKOFAImageFile(filename, f):
     retrieval = getUtility(IFileRetrieval)
     return retrieval.createFile(filename, f)